@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,8 +41,7 @@ static void     egg_idletime_finalize   (GObject       *object);
 
 struct EggIdletimePrivate
 {
-	int			 sync_event;
-	guint			 last_event;
+	gint			 sync_event;
 	gboolean		 reset_set;
 	XSyncCounter		 idle_counter;
 	GPtrArray		*array;
@@ -54,6 +53,7 @@ typedef struct
 	guint			 id;
 	XSyncValue		 timeout;
 	XSyncAlarm		 xalarm;
+	EggIdletime		*idletime;
 } EggIdletimeAlarm;
 
 enum {
@@ -73,6 +73,26 @@ static gpointer egg_idletime_object = NULL;
 
 G_DEFINE_TYPE (EggIdletime, egg_idletime, G_TYPE_OBJECT)
 
+/**
+ * egg_idletime_xsyncvalue_to_int64:
+ */
+static gint64
+egg_idletime_xsyncvalue_to_int64 (XSyncValue value)
+{
+	return ((guint64) XSyncValueHigh32 (value)) << 32 | (guint64) XSyncValueLow32 (value);
+}
+
+/**
+ * egg_idletime_get_time:
+ */
+gint64
+egg_idletime_get_time (EggIdletime *idletime)
+{
+	XSyncValue value;
+	XSyncQueryCounter (idletime->priv->dpy, idletime->priv->idle_counter, &value);
+	return egg_idletime_xsyncvalue_to_int64 (value);
+}
+
 /**
  * egg_idletime_xsync_alarm_set:
  */
@@ -181,7 +201,7 @@ egg_idletime_set_reset_alarm (EggIdletime *idletime, XSyncAlarmNotifyEvent *alar
 		 * idletime->priv->idle_counter < the current counter value */
 		egg_idletime_xsync_alarm_set (idletime, alarm, EGG_IDLETIME_ALARM_TYPE_NEGATIVE);
 
-		/* don't try to set this again if multiple timers are doing off in sequence */
+		/* don't try to set this again if multiple timers are going off in sequence */
 		idletime->priv->reset_set = TRUE;
 	}
 }
@@ -221,25 +241,42 @@ egg_idletime_event_filter_cb (GdkXEvent *gdkxevent, GdkEvent *event, gpointer da
 
 	/* did we match one of our alarms? */
 	alarm = egg_idletime_alarm_find_event (idletime, alarm_event);
-	if (alarm != NULL) {
-		/* save the last state we triggered */
-		idletime->priv->last_event = alarm->id;
+	if (alarm == NULL)
+		return GDK_FILTER_CONTINUE;
 
-		/* are we not the reset symbol */
-		if (alarm->id != 0) {
-			/* emit signal */
-			g_signal_emit (idletime, signals [SIGNAL_ALARM_EXPIRED], 0, alarm->id);
-
-			/* we need the first alarm to go off to set the reset alarm */
-			egg_idletime_set_reset_alarm (idletime, alarm_event);
-			return GDK_FILTER_CONTINUE;
-		}
-
-		/* do the reset callback */
+	/* are we the reset alarm? */
+	if (alarm->id == 0) {
 		egg_idletime_alarm_reset_all (idletime);
+		goto out;
 	}
 
-	return GDK_FILTER_CONTINUE;
+	/* emit */
+	g_signal_emit (alarm->idletime, signals [SIGNAL_ALARM_EXPIRED], 0, alarm->id);
+
+	/* we need the first alarm to go off to set the reset alarm */
+	egg_idletime_set_reset_alarm (idletime, alarm_event);
+out:
+	/* don't propagate */
+	return GDK_FILTER_REMOVE;
+}
+
+/**
+ * egg_idletime_alarm_new:
+ */
+static EggIdletimeAlarm *
+egg_idletime_alarm_new (EggIdletime *idletime, guint id)
+{
+	EggIdletimeAlarm *alarm;
+
+	/* create a new alarm */
+	alarm = g_new0 (EggIdletimeAlarm, 1);
+
+	/* set the default values */
+	alarm->id = id;
+	alarm->xalarm = None;
+	alarm->idletime = g_object_ref (idletime);
+
+	return alarm;
 }
 
 /**
@@ -258,11 +295,7 @@ egg_idletime_alarm_set (EggIdletime *idletime, guint id, guint timeout)
 	alarm = egg_idletime_alarm_find_id (idletime, id);
 	if (alarm == NULL) {
 		/* create a new alarm */
-		alarm = g_new0 (EggIdletimeAlarm, 1);
-
-		/* set the default values */
-		alarm->id = id;
-		alarm->xalarm = None;
+		alarm = egg_idletime_alarm_new (idletime, id);
 
 		/* add to array */
 		g_ptr_array_add (idletime->priv->array, alarm);
@@ -282,8 +315,12 @@ egg_idletime_alarm_set (EggIdletime *idletime, guint id, guint timeout)
 static gboolean
 egg_idletime_alarm_free (EggIdletime *idletime, EggIdletimeAlarm *alarm)
 {
+	g_return_val_if_fail (EGG_IS_IDLETIME (idletime), FALSE);
+	g_return_val_if_fail (alarm != NULL, FALSE);
+
 	if (alarm->xalarm)
 		XSyncDestroyAlarm (idletime->priv->dpy, alarm->xalarm);
+	g_object_unref (alarm->idletime);
 	g_free (alarm);
 	g_ptr_array_remove (idletime->priv->array, alarm);
 	return TRUE;
@@ -348,8 +385,8 @@ egg_idletime_init (EggIdletime *idletime)
 
 	idletime->priv->array = g_ptr_array_new ();
 
+	idletime->priv->reset_set = FALSE;
 	idletime->priv->idle_counter = None;
-	idletime->priv->last_event = 0;
 	idletime->priv->sync_event = 0;
 	idletime->priv->dpy = GDK_DISPLAY ();
 
@@ -373,15 +410,11 @@ egg_idletime_init (EggIdletime *idletime)
 		return;
 	}
 
-	idletime->priv->reset_set = FALSE;
-
 	/* catch the timer alarm */
 	gdk_window_add_filter (NULL, egg_idletime_event_filter_cb, idletime);
 
 	/* create a reset alarm */
-	alarm = g_new0 (EggIdletimeAlarm, 1);
-	alarm->id = 0;
-	alarm->xalarm = None;
+	alarm = egg_idletime_alarm_new (idletime, 0);
 	g_ptr_array_add (idletime->priv->array, alarm);
 }
 
@@ -518,10 +551,10 @@ egg_idletime_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check if we are alarm zero with no alarms");
-	if (idletime->priv->last_event == 0) {
+	if (last_alarm == 0) {
 		egg_test_success (test, NULL);
 	} else {
-		egg_test_failed (test, "alarm %i set!", idletime->priv->last_event);
+		egg_test_failed (test, "alarm %i set!", last_alarm);
 	}
 
 	/************************************************************/
@@ -577,10 +610,10 @@ egg_idletime_test (gpointer data)
 
 		/************************************************************/
 		egg_test_title (test, "check if correct alarm has gone off");
-		if (idletime->priv->last_event == 101) {
+		if (last_alarm == 101) {
 			egg_test_success (test, "correct alarm");
 		} else {
-			egg_test_failed (test, "alarm %i set!", idletime->priv->last_event);
+			egg_test_failed (test, "alarm %i set!", last_alarm);
 		}
 
 		/************************************************************/
@@ -588,7 +621,7 @@ egg_idletime_test (gpointer data)
 		if (event_time > 3000 && event_time < 6000) {
 			egg_test_success (test, "correct, timeout ideally %ims (we did after %ims)", 5000, event_time);
 		} else {
-			egg_test_failed (test, "alarm %i did not timeout correctly !", idletime->priv->last_event);
+			egg_test_failed (test, "alarm %i did not timeout correctly !", last_alarm);
 		}
 	}
 
