@@ -59,7 +59,7 @@
 #include "gpm-prefs-server.h"
 #include "gpm-tray-icon.h"
 #include "gpm-engine.h"
-#include "gpm-devicekit.h"
+#include "gpm-upower.h"
 #include "gpm-disks.h"
 
 #include "org.gnome.PowerManager.Backlight.h"
@@ -1297,7 +1297,7 @@ gpm_manager_engine_discharging_cb (GpmEngine *engine, DkpDevice *device, GpmMana
 		goto out;
 	}
 
-	icon = gpm_devicekit_get_object_icon (device);
+	icon = gpm_upower_get_device_icon (device);
 	/* show the notification */
 	gpm_manager_notify (manager, &manager->priv->notification_discharging, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_LONG,
 			    icon, NOTIFY_URGENCY_NORMAL);
@@ -1419,7 +1419,7 @@ gpm_manager_engine_charge_low_cb (GpmEngine *engine, DkpDevice *device, GpmManag
 	}
 
 	/* get correct icon */
-	icon = gpm_devicekit_get_object_icon (device);
+	icon = gpm_upower_get_device_icon (device);
 	gpm_manager_notify (manager, &manager->priv->notification, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_LONG, icon, NOTIFY_URGENCY_NORMAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
 out:
@@ -1435,7 +1435,6 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, DkpDevice *device, Gpm
 {
 	const gchar *title = NULL;
 	gchar *message = NULL;
-	gchar *remaining_text;
 	gchar *action;
 	gchar *icon = NULL;
 	DkpDeviceType type;
@@ -1471,8 +1470,6 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, DkpDevice *device, Gpm
 			title = _("Laptop battery critically low");
 		}
 
-		remaining_text = gpm_get_timestring (time_to_empty);
-
 		/* we have to do different warnings depending on the policy */
 		action = gconf_client_get_string (manager->priv->conf, GPM_CONF_ACTIONS_CRITICAL_BATT, NULL);
 		policy = gpm_action_policy_from_string (action);
@@ -1484,20 +1481,21 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, DkpDevice *device, Gpm
 
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND) {
 			/* TRANSLATORS: give the user a ultimatum */
-			message = g_strdup_printf (_("Computer will suspend in %s."), remaining_text);
+			message = g_strdup_printf (_("Computer will suspend very soon unless it is plugged in."));
 
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE) {
 			/* TRANSLATORS: give the user a ultimatum */
-			message = g_strdup_printf (_("Computer will hibernate in %s."), remaining_text);
+			message = g_strdup_printf (_("Computer will hibernate very soon unless it is plugged in."));
 
 		} else if (policy == GPM_ACTION_POLICY_SHUTDOWN) {
 			/* TRANSLATORS: give the user a ultimatum */
-			message = g_strdup_printf (_("Computer will shutdown in %s."), remaining_text);
+			message = g_strdup_printf (_("Computer will shutdown very soon unless it is plugged in."));
 		}
 
 		g_free (action);
-		g_free (remaining_text);
 	} else if (type == DKP_DEVICE_TYPE_UPS) {
+		gchar *remaining_text;
+
 		/* TRANSLATORS: the UPS is very low */
 		title = _("UPS critically low");
 		remaining_text = gpm_get_timestring (time_to_empty);
@@ -1544,8 +1542,8 @@ gpm_manager_engine_charge_critical_cb (GpmEngine *engine, DkpDevice *device, Gpm
 	}
 
 	/* get correct icon */
-	icon = gpm_devicekit_get_object_icon (device);
-	gpm_manager_notify (manager, &manager->priv->notification, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_LONG, icon, NOTIFY_URGENCY_CRITICAL);
+	icon = gpm_upower_get_device_icon (device);
+	gpm_manager_notify (manager, &manager->priv->notification, title, message, GPM_MANAGER_NOTIFY_TIMEOUT_NEVER, icon, NOTIFY_URGENCY_CRITICAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
 out:
 	g_free (icon);
@@ -1614,8 +1612,8 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, DkpDevice *device, GpmMa
 
 		g_free (action);
 
-		/* wait 10 seconds for user-panic */
-		g_timeout_add_seconds (10, (GSourceFunc) manager_critical_action_do, manager);
+		/* wait 20 seconds for user-panic */
+		g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
 
 	} else if (type == DKP_DEVICE_TYPE_UPS) {
 		/* TRANSLATORS: UPS is really, really, low */
@@ -1651,9 +1649,9 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, DkpDevice *device, GpmMa
 		return;
 
 	/* get correct icon */
-	icon = gpm_devicekit_get_object_icon (device);
+	icon = gpm_upower_get_device_icon (device);
 	gpm_manager_notify (manager, &manager->priv->notification,
-			    title, message, GPM_MANAGER_NOTIFY_TIMEOUT_LONG,
+			    title, message, GPM_MANAGER_NOTIFY_TIMEOUT_NEVER,
 			    icon, NOTIFY_URGENCY_CRITICAL);
 	gpm_manager_play (manager, GPM_MANAGER_SOUND_BATTERY_LOW, TRUE);
 out:
@@ -1692,6 +1690,14 @@ static gboolean
 gpm_manager_reset_just_resumed_cb (gpointer user_data)
 {
 	GpmManager *manager = GPM_MANAGER (user_data);
+
+	if (manager->priv->notification != NULL)
+		gpm_manager_notify_close (manager, manager->priv->notification);
+	if (manager->priv->notification_discharging != NULL)
+		gpm_manager_notify_close (manager, manager->priv->notification_discharging);
+	if (manager->priv->notification_fully_charged != NULL)
+		gpm_manager_notify_close (manager, manager->priv->notification_fully_charged);
+
 	manager->priv->just_resumed = FALSE;
 	return FALSE;
 }
