@@ -38,7 +38,7 @@
 
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
-#include "gpm-devicekit.h"
+#include "gpm-upower.h"
 #include "gpm-graph-widget.h"
 
 static GtkBuilder *builder = NULL;
@@ -1145,7 +1145,7 @@ gpm_stats_add_device (DkpDevice *device)
 
 	id = dkp_device_get_object_path (device);
 	text = gpm_device_type_to_localised_text (type, 1);
-	icon = gpm_devicekit_get_object_icon (device);
+	icon = gpm_upower_get_device_icon (device);
 
 	gtk_list_store_append (list_store_devices, &iter);
 	gtk_list_store_set (list_store_devices, &iter,
@@ -1241,7 +1241,7 @@ gpm_stats_history_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 		history_type = GPM_HISTORY_CHARGE_VALUE;
 		/* TRANSLATORS: this is the X axis on the graph */
 		axis_x = _("Time elapsed");
-		/* TRANSLATORS: this is the Y axis on the graph */
+		/* TRANSLATORS: this is the Y axis on the graph for the whole battery device */
 		axis_y = _("Cell charge");
 	} else if (g_strcmp0 (value, GPM_HISTORY_TIME_FULL_TEXT) == 0) {
 		history_type = GPM_HISTORY_TIME_FULL_VALUE;
@@ -1284,25 +1284,25 @@ gpm_stats_type_combo_changed_cb (GtkWidget *widget, gpointer data)
 	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
 	if (g_strcmp0 (value, GPM_STATS_CHARGE_DATA_TEXT) == 0) {
 		stats_type = GPM_STATS_CHARGE_DATA_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Correction factor");
 	} else if (g_strcmp0 (value, GPM_STATS_CHARGE_ACCURACY_TEXT) == 0) {
 		stats_type = GPM_STATS_CHARGE_ACCURACY_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Prediction accuracy");
 	} else if (g_strcmp0 (value, GPM_STATS_DISCHARGE_DATA_TEXT) == 0) {
 		stats_type = GPM_STATS_DISCHARGE_DATA_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Correction factor");
 	} else if (g_strcmp0 (value, GPM_STATS_DISCHARGE_ACCURACY_TEXT) == 0) {
 		stats_type = GPM_STATS_DISCHARGE_ACCURACY_VALUE;
-		/* TRANSLATORS: this is the X axis on the graph */
+		/* TRANSLATORS: this is the X axis on the graph for the whole battery device */
 		axis_x = _("Cell charge");
 		/* TRANSLATORS: this is the Y axis on the graph */
 		axis_y = _("Prediction accuracy");
